use std::cmp::Ordering;

#[path = "../lib.rs"]
mod lib;

fn parse_input() -> (Vec<(u8, u8)>, Vec<Vec<u8>>) {
    let mut state = true;
    let mut rules = vec![];
    let mut updates = vec![];

    for line in lib::iter_input() {
        if line == "" {
            state = false;
        } else if state {
            let (a, b) = line.split_once('|').unwrap();
            rules.push((a.parse::<u8>().unwrap(), b.parse::<u8>().unwrap()));
        } else {
            updates.push(line.split(',').map(|s| s.parse::<u8>().unwrap()).collect());
        }
    }

    return (rules, updates);
}

fn order(update: &Vec<u8>, rules: &Vec<(u8, u8)>) -> Vec<u8> {
    let mut clone = update.clone();
    clone.sort_by(|a, b| {
        if rules.contains(&(*a, *b)) {
            return Ordering::Less;
        } else if rules.contains(&(*b, *a)) {
            return Ordering::Greater;
        } else {
            return Ordering::Equal;
        }
    });
    return clone;
}

fn main() {
    let (rules, updates) = parse_input();

    let mut count1 = 0;
    let mut count2 = 0;

    for update in updates.iter() {
        let ordered = order(update, &rules);
        if ordered == *update {
            count1 += ordered[ordered.len() / 2] as u64;
        } else {
            count2 += ordered[ordered.len() / 2] as u64;
        }
    }

    println!("part1: {}", count1);
    println!("part2: {}", count2);
}
